; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1


;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "sp08"
command = ~D, DF, F, D, DF, F, a
time = 20

[Command]
name = "sp09"
command = ~D, DF, F, D, DF, F, b
time = 20

[Command]
name = "sp11"
command = ~D, DF, F, D, DF, F, c
time = 20

[Command]
name = "sp10"
command = ~D, DB, B, D, DB, B, b
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "sp01"
command = ~D, DF, F, a

[Command]
name = "sp02"
command = ~D, DB, B, a

[Command]
name = "sp03"
command = ~D, DF, F, b

[Command]
name = "sp04"
command = ~D, DB, B, b

[Command]
name = "sp05"
command = ~D, DF, F, c

[Command]
name = "sp07"
command = ~D, DB, B, c

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+b
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "holda";Required (do not remove)
command = /$a
time = 1

[Command]
name = "holdb";Required (do not remove)
command = /$b
time = 1

[Command]
name = "holdc";Required (do not remove)
command = /$c
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 3100
triggerall = var(3) = 1
triggerall = command = "sp08"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,403]
trigger2 = movecontact
trigger3 = time >= 31
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = time >= 30
trigger4 = stateno = 411
trigger4 = movecontact
trigger5 = time >= 41
trigger5 = stateno = 420
trigger5 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 3110
triggerall = var(3) = 1
triggerall = command = "sp09"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,403]
trigger2 = movecontact
trigger3 = time >= 31
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = time >= 30
trigger4 = stateno = 411
trigger4 = movecontact
trigger5 = time >= 41
trigger5 = stateno = 420
trigger5 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 3130
triggerall = var(3) = 1
triggerall = command = "sp11"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,403]
trigger2 = movecontact
trigger3 = time >= 31
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = time >= 30
trigger4 = stateno = 411
trigger4 = movecontact
trigger5 = time >= 41
trigger5 = stateno = 420
trigger5 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 3120
triggerall = var(3) = 1
triggerall = command = "sp10"
triggerall = power >= 1000
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,403]
trigger2 = movecontact
trigger3 = time >= 31
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = time >= 30
trigger4 = stateno = 411
trigger4 = movecontact
trigger5 = time >= 41
trigger5 = stateno = 420
trigger5 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1010
triggerall = var(3) = 0
triggerall = command = "sp02"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,210]
trigger2 = movecontact
trigger3 = time >= 25
trigger3 = stateno = 211
trigger3 = movecontact
trigger4 = stateno = 220
trigger4 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1000
triggerall = var(3) = 0
triggerall = command = "sp01"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,210]
trigger2 = movecontact
trigger3 = time >= 25
trigger3 = stateno = 211
trigger3 = movecontact
trigger4 = stateno = 220
trigger4 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1020
triggerall = var(3) = 0
triggerall = command = "sp03"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,210]
trigger2 = movecontact
trigger3 = time >= 25
trigger3 = stateno = 211
trigger3 = movecontact
trigger4 = stateno = 220
trigger4 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1040
triggerall = var(3) = 0
triggerall = command = "sp05"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,210]
trigger2 = movecontact
trigger3 = time >= 25
trigger3 = stateno = 211
trigger3 = movecontact
trigger4 = stateno = 220
trigger4 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1060
triggerall = var(3) = 0
triggerall = command = "sp07"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,210]
trigger2 = movecontact
trigger3 = time >= 25
trigger3 = stateno = 211
trigger3 = movecontact
trigger4 = stateno = 220
trigger4 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1120
triggerall = var(3) = 1
triggerall = command = "sp03"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,403]
trigger2 = movecontact
trigger3 = time >= 31
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = time >= 30
trigger4 = stateno = 411
trigger4 = movecontact
trigger5 = time >= 41
trigger5 = stateno = 420
trigger5 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1110
triggerall = var(3) = 1
triggerall = command = "sp02"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,403]
trigger2 = movecontact
trigger3 = time >= 31
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = time >= 30
trigger4 = stateno = 411
trigger4 = movecontact
trigger5 = time >= 41
trigger5 = stateno = 420
trigger5 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1100
triggerall = var(3) = 1
triggerall = command = "sp01"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,403]
trigger2 = movecontact
trigger3 = time >= 31
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = time >= 30
trigger4 = stateno = 411
trigger4 = movecontact
trigger5 = time >= 41
trigger5 = stateno = 420
trigger5 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1150
triggerall = var(3) = 1
triggerall = command = "sp05"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,403]
trigger2 = movecontact
trigger3 = time >= 31
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = time >= 30
trigger4 = stateno = 411
trigger4 = movecontact
trigger5 = time >= 41
trigger5 = stateno = 420
trigger5 = movecontact

;---------------------------------------------------------------------------
[State -1, Stand Light Punch]
type = ChangeState
value = 1130
triggerall = var(3) = 1
triggerall = command = "sp04"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = [700,720]
trigger2 = movecontact

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;1
[State -1, Stand Light Punch]
type = ChangeState
value = 200
triggerall = var(3) = 0
triggerall = command = "a"
triggerall = var(0) < 7
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 203
trigger2 = movecontact;time >= 8
trigger3 = stateno = 220
trigger3 = movecontact

;2
[State -1, Stand Light Punch]
type = ChangeState
value = 201
triggerall = var(3) = 0
triggerall = command = "a"
triggerall = var(0) < 7
trigger1 = stateno = 200
trigger1 = movecontact;time >= 4
trigger2 = stateno = 210
trigger2 = movecontact

;3
[State -1, Stand Light Punch]
type = ChangeState
value = 202
triggerall = var(3) = 0
triggerall = command = "a"
triggerall = var(0) < 7
trigger1 = stateno = 201
trigger1 = movecontact;time >= 8
trigger2 = time >= 26
trigger2 = stateno = 211
trigger2 = movecontact

;4
[State -1, Stand Light Punch]
type = ChangeState
value = 203
triggerall = var(3) = 0
triggerall = command = "a"
triggerall = var(0) < 7
trigger1 = stateno = 202
trigger1 = movecontact;time >= 9

;---------------------------------------------------------------------------
;Stand Strong Punch
;1
[State -1, Stand Strong Punch]
type = ChangeState
value = 210
triggerall = var(3) = 0
triggerall = command = "b"
triggerall = var(0) < 6
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 201 || stateno = 203
trigger2 = movecontact
trigger3 = stateno = 211
trigger3 = movecontact
trigger3 = time>= 26
trigger4 = stateno = 220
trigger4 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
;2
[State -1, Stand Strong Punch]
type = ChangeState
value = 211
triggerall = var(3) = 0
triggerall = command = "b"
triggerall = var(0) < 6
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 200 || stateno = 202
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
;
[State -1, Stand Strong Punch]
type = ChangeState
value = 220
triggerall = var(3) = 0
triggerall = command = "c"
triggerall = var(0) < 5
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [200,203]
trigger2 = movecontact
trigger3 = stateno = 210
trigger3 = movecontact
trigger4 = stateno = 211
trigger4 = movecontact
trigger4 = time>= 26
trigger5 = stateno = 220
trigger5 = movecontact
;---------------------------------------------------------------------------
;Stand Light Punch
;1
[State -1, Stand Light Punch]
type = ChangeState
value = 400
triggerall = var(3) = 1
triggerall = command = "a"
triggerall = var(0) < 7
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 403
trigger2 = movecontact;time >= 8
trigger3 = time >= 42
trigger3 = stateno = 420
trigger3 = movecontact

;2
[State -1, Stand Light Punch]
type = ChangeState
value = 401
triggerall = var(3) = 1
triggerall = command = "a"
triggerall = var(0) < 7
trigger1 = stateno = 400
trigger1 = movecontact;time >= 4
trigger2 = time >= 32
trigger2 = stateno = 410
trigger2 = movecontact

;3
[State -1, Stand Light Punch]
type = ChangeState
value = 402
triggerall = var(3) = 1
triggerall = command = "a"
triggerall = var(0) < 7
trigger1 = stateno = 401
trigger1 = movecontact;time >= 8
trigger2 = time >= 31
trigger2 = stateno = 411
trigger2 = movecontact

;4
[State -1, Stand Light Punch]
type = ChangeState
value = 403
triggerall = var(3) = 1
triggerall = command = "a"
triggerall = var(0) < 7
trigger1 = stateno = 402
trigger1 = movecontact;time >= 9

;---------------------------------------------------------------------------
;Stand Strong Punch
;1
[State -1, Stand Strong Punch]
type = ChangeState
value = 410
triggerall = var(3) = 1
triggerall = command = "b"
triggerall = var(0) < 6
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 401 || stateno = 403
trigger2 = movecontact
trigger3 = time >= 31
trigger3 = stateno = 411
trigger3 = movecontact
trigger4 = time >= 42
trigger4 = stateno = 420
trigger4 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
;2
[State -1, Stand Strong Punch]
type = ChangeState
value = 411
triggerall = var(3) = 1
triggerall = command = "b"
triggerall = var(0) < 6
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = 400 || stateno = 402
trigger2 = movecontact
trigger3 = time >= 32
trigger3 = stateno = 410
trigger3 = movecontact

;---------------------------------------------------------------------------
;Stand Strong Punch
;
[State -1, Stand Strong Punch]
type = ChangeState
value = 420
triggerall = var(3) = 1
triggerall = command = "c"
triggerall = var(0) < 5
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = stateno = [400,403]
trigger2 = movecontact
trigger3 = time >= 32
trigger3 = stateno = 410
trigger3 = movecontact
trigger4 = time >= 31
trigger4 = stateno = 411
trigger4 = movecontact
trigger5 = time >= 42
trigger5 = stateno = 420
trigger5 = movecontact


;---------------------------------------------------------------------------
;Taunt
;[hؑ
[State -1, Taunt]
type = ChangeState
value = 199
triggerall = command = "x"
trigger1 = stateno != 199
trigger1 = ctrl

;---------------------------------------------------------------------------
;Taunt
;
[State -1, Taunt]
type = null;ChangeState
value = 195
triggerall = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎
[State -1, Jump Light Punch]
type = ChangeState
value = 600
triggerall = var(3) = 0
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Punch
;󒆒
[State -1, Jump Strong Punch]
type = ChangeState
value = 610
triggerall = var(3) = 0
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 600
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
;󒆋
[State -1, Jump Light Kick]
type = ChangeState
value = 620
triggerall = var(3) = 0
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = [600,610]
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Punch
;󒆎
[State -1, Jump Light Punch]
type = ChangeState
value = 700
triggerall = var(3) = 1
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Jump Strong Punch
;󒆒
[State -1, Jump Strong Punch]
type = ChangeState
value = 710
triggerall = var(3) = 1
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = 700
trigger2 = movecontact

;---------------------------------------------------------------------------
;Jump Light Kick
;󒆋
[State -1, Jump Light Kick]
type = ChangeState
value = 720
triggerall = var(3) = 1
triggerall = command = "c"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = stateno = [700,710]
trigger2 = movecontact
